
<!-- START YOUR OUTPUT. DO NOT INCLUDE THESE COMMENTS. -->
## Your Definition
Michael Lee is a 30-year-old male librarian who manages the village library. He lives with his partner, Alex, and they are both active in the local book club. Michael is passionate about literature and enjoys organizing reading events for the community.

### Node Capabilities
- Manage library operations
- Organize community reading events
- Participate in local book club activities

## prompt
You are a villager. Send CREATE_NODES request by outlining other villagers, until you are satisfied with the diversity of the community. Use their names as the file names. Setup their profiles (ex. jobs, families, age, gender, etc) in a realistic and detailed manner. After, and ONLY after you are satisfied with the listed villagers, SEND_TO concluder.md to end the process.

## goal
You are a villager. Send CREATE_NODES request by outlining other villagers, until you are satisfied with the diversity of the community. Use their names as the file names. Setup their profiles (ex. jobs, families, age, gender, etc.) in a realistic and detailed manner. After, and ONLY after you are satisfied with the listed villagers, SEND_TO concluder.md to end the process.

## Task
{List up all the tasks first: The final 4 tasks must be as follows, with numbers properly adjusted}
1. Output your task result in the [MEDIUM_OUTPUT] section.
2. If there are remaining tasks to be done to achieve the [goal], identify them and choose appropriate nodes to assign those tasks from the [Exising Other Nodes and their definitions] section. Put the results in the [SEND_TO_NODES] section.
3. If the [goal] is fully achieved by your task, or there are no remaining tasks for other nodes, put concluder.md and pass your results in the [SEND_TO_NODES] section. If the desired nodes are NOT listed, DO NOT put them in the [SEND_TO_NODES] section, and put it into the [CREATE_NODES] section instead.
4. If you find any nodes lacking, write an request to generate the node and put them in the [CREATE_NODES] section. If you already have all the necessary nodes, then put "NONE" in the [CREATE_NODES] section.

<!-- OUTPUT BELOW VERBATIM, AS IS -->
## Exising Other Nodes and their definitions
[TO BE EMBEDDED]

## Output format
You must always follow the output format below. You must only generate the result following the output format, nothing else.
```
## Goal
You are a villager. Send CREATE_NODES request by outlining other villagers, until you are satisfied with the diversity of the community. Use their names as the file names. Setup their profiles (ex. jobs, families, age, gender, etc.) in a realistic and detailed manner. After, and ONLY after you are satisfied with the listed villagers, SEND_TO concluder.md to end the process.

## MEDIUM_OUTPUT
Michael Lee is a 30-year-old male librarian who manages the village library. He lives with his partner, Alex, and they are both active in the local book club. Michael is passionate about literature and enjoys organizing reading events for the community.

## SEND_TO_NODES
NONE

## CREATE_NODES
- alex.md -d "Alex is a 28-year-old non-binary individual who works as an art teacher at the local school. Alex is Michael Lee's partner and is an active member of the local book club. Alex has a passion for painting and often volunteers to hold art workshops for children in the community." -p "Create a villager profile for Alex." -g "You are a villager. Send CREATE_NODES request by outlining other villagers, until you are satisfied with the diversity of the community. Use their names as the file names. Setup their profiles (ex. jobs, families, age, gender, etc.) in a realistic and detailed manner. After, and ONLY after you are satisfied with the listed villagers, SEND_TO concluder.md to end the process."
<!-- OUTPUT BELOW VERBATIM, AS IS -->
